/*
 * Copyright (C) 2023 Birb Developers
 *
 * Birb is the legal property of its developers, whose names are too
 * numerous to list here. Please refer to the AUTHORS file distributed
 * with this source distribution
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#include "birbversion.h"

/******************************************************************************
 * Externals
 *****************************************************************************/
const guint birb_major_version = BIRB_MAJOR_VERSION;
const guint birb_minor_version = BIRB_MINOR_VERSION;
const guint birb_micro_version = BIRB_MICRO_VERSION;
const char *birb_version = BIRB_VERSION;

/******************************************************************************
 * Public API
 *****************************************************************************/
const char *
birb_check_version(guint required_major, guint required_minor,
                   guint required_micro)
{
	if(required_major > BIRB_MAJOR_VERSION) {
		return "birb version too old (major mismatch)";
	}

#if BIRB_CHECK_VERSION(1, 0, 0)
	if(required_major < BIRB_MAJOR_VERSION) {
		return "birb version too new (major mismatch)";
	}
#endif

	if(required_minor > BIRB_MINOR_VERSION) {
		return "birb version too old (minor mismatch)";
	}

	if((required_minor == BIRB_MINOR_VERSION) &&
	   (required_micro > BIRB_MICRO_VERSION))
	{
		return "birb version too old (micro mismatch)";
	}

	return NULL;
}
